@@ -1,49 +1,48 @@
-use 5.010;
-use strict;
-use warnings;
-
 package Git::Hooks;
 {
-  $Git::Hooks::VERSION = '0.023';
+  $Git::Hooks::VERSION = '0.024';
 }
 # ABSTRACT: A framework for implementing Git hooks.
 
+use 5.010;
+use strict;
+use warnings;
 use Exporter qw/import/;
 use Data::Util qw(:all);
 use File::Basename;
 use File::Spec::Functions;
 use Git::More;
 
-our %Hooks;
-our (@EXPORT, @EXPORT_OK, %EXPORT_TAGS);
+our (@EXPORT, @EXPORT_OK, %EXPORT_TAGS); ## no critic (Modules::ProhibitAutomaticExportation)
+my %Hooks;
 
-BEGIN {
+BEGIN {                ## no critic (Subroutines::RequireArgUnpacking)
     my @installers =
-	qw/ APPLYPATCH_MSG PRE_APPLYPATCH POST_APPLYPATCH
-	    PRE_COMMIT PREPARE_COMMIT_MSG COMMIT_MSG
-	    POST_COMMIT PRE_REBASE POST_CHECKOUT POST_MERGE
-	    PRE_RECEIVE UPDATE POST_RECEIVE POST_UPDATE
-	    PRE_AUTO_GC POST_REWRITE /;
+        qw/ APPLYPATCH_MSG PRE_APPLYPATCH POST_APPLYPATCH
+            PRE_COMMIT PREPARE_COMMIT_MSG COMMIT_MSG
+            POST_COMMIT PRE_REBASE POST_CHECKOUT POST_MERGE
+            PRE_RECEIVE UPDATE POST_RECEIVE POST_UPDATE
+            PRE_AUTO_GC POST_REWRITE /;
 
     for my $installer (@installers) {
-	my $hook = lc $installer;
-	$hook =~ tr/_/-/;
-	install_subroutine(
-	    __PACKAGE__,
-	    $installer => sub (&) {
-		my ($foo) = @_;
-		$Hooks{$hook}{$foo} ||= sub { $foo->(@_); };
-	    }
-	);
+        my $hook = lc $installer;
+        $hook =~ tr/_/-/;
+        install_subroutine(
+            __PACKAGE__,
+            $installer => sub (&) {
+                my ($foo) = @_;
+                $Hooks{$hook}{$foo} ||= sub { $foo->(@_); };
+            }
+        );
     }
 
     @EXPORT      = (@installers, 'run_hook');
 
     @EXPORT_OK = qw/repository hook_config is_ref_enabled
-		    get_affected_refs get_affected_ref_commits
-		    get_affected_ref_range im_memberof grok_userenv
-		    match_user im_admin eval_gitconfig
-		    flatten_plugin_name unflatten_plugin_name/;
+                    get_affected_refs get_affected_ref_commits
+                    get_affected_ref_range im_memberof grok_userenv
+                    match_user im_admin eval_gitconfig
+                    flatten_plugin_name unflatten_plugin_name/;
 
     %EXPORT_TAGS = (utils => \@EXPORT_OK);
 }
@@ -66,11 +65,11 @@ sub hook_config {
 sub is_ref_enabled {
     my ($specs, $ref) = @_;
     foreach (@$specs) {
-	if (/^\^/) {
-	    return 1 if $ref =~ qr/$_/;
-	} else {
-	    return 1 if $ref eq $_;
-	}
+        if (/^\^/) {
+            return 1 if $ref =~ qr/$_/;
+        } else {
+            return 1 if $ref eq $_;
+        }
     }
     return 0;
 }
@@ -83,17 +82,18 @@ my %affected_refs;
 sub grok_affected_refs {
     my ($hook_name) = @_;
     if ($hook_name eq 'update') {
-	my ($ref, $old_commit, $new_commit) = @ARGV;
-	$affected_refs{$ref}{range} = [$old_commit, $new_commit];
+        my ($ref, $old_commit, $new_commit) = @ARGV;
+        $affected_refs{$ref}{range} = [$old_commit, $new_commit];
     } elsif ($hook_name =~ /^(?:pre|post)-receive$/) {
-	# pre-receive and post-receive get the list of affected
-	# commits via STDIN.
-	while (<>) {
-	    chomp;
-	    my ($old_commit, $new_commit, $ref) = split;
-	    $affected_refs{$ref}{range} = [$old_commit, $new_commit];
-	}
+        # pre-receive and post-receive get the list of affected
+        # commits via STDIN.
+        while (<>) {
+            chomp;
+            my ($old_commit, $new_commit, $ref) = split;
+            $affected_refs{$ref}{range} = [$old_commit, $new_commit];
+        }
     }
+    return;
 }
 
 sub get_affected_refs {
@@ -104,7 +104,7 @@ sub get_affected_ref_range {
     my ($ref) = @_;
 
     exists $affected_refs{$ref}
-	or die __PACKAGE__, ": internal error: no such affected ref ($ref)";
+        or die __PACKAGE__, ": internal error: no such affected ref ($ref)\n";
     return @{$affected_refs{$ref}{range}};
 }
 
@@ -112,8 +112,8 @@ sub get_affected_ref_commit_ids {
     my ($ref) = @_;
 
     unless (exists $affected_refs{$ref}{ids}) {
-	my $range = get_affected_ref_range($ref);
-	$affected_refs{$ref}{ids} = [repository()->command('rev-list' => join('..', @$range))];
+        my $range = get_affected_ref_range($ref);
+        $affected_refs{$ref}{ids} = [repository()->command('rev-list' => join('..', @$range))];
     }
 
     return $affected_refs{$ref}{ids};
@@ -123,7 +123,7 @@ sub get_affected_ref_commits {
     my ($ref) = @_;
 
     unless (exists $affected_refs{$ref}{commits}) {
-	$affected_refs{$ref}{commits} = repository()->get_commits(get_affected_ref_range($ref));
+        $affected_refs{$ref}{commits} = repository()->get_commits(get_affected_ref_range($ref));
     }
 
     return $affected_refs{$ref}{commits};
@@ -137,31 +137,31 @@ sub spawn_external_file {
 
     my $exit;
     if ($hook !~ /^(?:pre|post)-receive$/) {
-	$exit = system {$file} ($hook, @args);
+        $exit = system {$file} ($hook, @args);
     } else {
-	my $pid = open my $pipe, '|-';
-	if (! defined $pid) {
-	    die __PACKAGE__, ": can't fork: $!\n";
-	} elsif ($pid) {
-	    # parent
-	    foreach my $ref (get_affected_refs()) {
-		my ($old, $new) = get_affected_ref_range($ref);
-		say $pipe "$old $new $ref";
-	    }
-	    $exit = close $pipe;
-	} else {
-	    # child
-	    exec {$file} ($hook, @args);
-	    die __PACKAGE__, ": can't exec: $!\n";
-	}
+        my $pid = open my $pipe, '|-';
+        if (! defined $pid) {
+            die __PACKAGE__, ": can't fork: $!\n";
+        } elsif ($pid) {
+            # parent
+            foreach my $ref (get_affected_refs()) {
+                my ($old, $new) = get_affected_ref_range($ref);
+                say $pipe "$old $new $ref";
+            }
+            $exit = close $pipe;
+        } else {
+            # child
+            exec {$file} ($hook, @args);
+            die __PACKAGE__, ": can't exec: $!\n";
+        }
     }
     unless ($exit == 0) {
-	die __PACKAGE__, ": failed to execute '$file': $!\n"
-	    if $exit == -1;
-	die sprintf("%s: '$file' died with signal %d, %s coredump\n",
-		    __PACKAGE__, ($exit & 127), ($exit & 128) ? 'with' : 'without')
-	    if $exit & 127;
-	die sprintf("%s: '$file' exited abnormally with value %d\n", __PACKAGE__, $exit >> 8);
+        die __PACKAGE__, ": failed to execute '$file': $!\n"
+            if $exit == -1;
+        die sprintf("%s: '$file' died with signal %d, %s coredump",
+                    __PACKAGE__, ($exit & 127), ($exit & 128) ? 'with' : 'without'), "\n"
+            if $exit & 127;
+        die sprintf("%s: '$file' exited abnormally with value %d", __PACKAGE__, $exit >> 8), "\n";
     }
 }
 
@@ -169,43 +169,43 @@ sub grok_groups_spec {
     my ($specs, $source) = @_;
     my %groups;
     foreach (@$specs) {
-	s/\#.*//;		# strip comments
-	next unless /\S/;	# skip blank lines
-	/^\s*(\w+)\s*=\s*(.+?)\s*$/
-	    or die __PACKAGE__, ": invalid line in group file '$source': $_\n";
-	my ($groupname, $members) = ($1, $2);
-	exists $groups{"\@$groupname"}
-	    and die __PACKAGE__, ": redefinition of group ($groupname) in '$source': $_\n";
-	foreach my $member (split / /, $members) {
-	    if ($member =~ /^\@/) {
-		# group member
-		$groups{"\@$groupname"}{$member} = $groups{$member}
-		    or die __PACKAGE__, ": unknown group ($member) cited in '$source': $_\n";
-	    } else {
-		# user member
-		$groups{"\@$groupname"}{$member} = undef;
-	    }
-	}
+        s/\#.*//;               # strip comments
+        next unless /\S/;       # skip blank lines
+        /^\s*(\w+)\s*=\s*(.+?)\s*$/
+            or die __PACKAGE__, ": invalid line in group file '$source': $_\n";
+        my ($groupname, $members) = ($1, $2);
+        exists $groups{"\@$groupname"}
+            and die __PACKAGE__, ": redefinition of group ($groupname) in '$source': $_\n";
+        foreach my $member (split / /, $members) {
+            if ($member =~ /^\@/) {
+                # group member
+                $groups{"\@$groupname"}{$member} = $groups{$member}
+                    or die __PACKAGE__, ": unknown group ($member) cited in '$source': $_\n";
+            } else {
+                # user member
+                $groups{"\@$groupname"}{$member} = undef;
+            }
+        }
     }
     return \%groups;
 }
 
 sub grok_groups {
     state $groups = do {
-	my $config = config();
-	exists $config->{githooks}{groups}
-	    or die __PACKAGE__, ": you have to define the githooks.groups option to use groups.\n";
-	my $option = $config->{githooks}{groups};
+        my $config = config();
+        exists $config->{githooks}{groups}
+            or die __PACKAGE__, ": you have to define the githooks.groups option to use groups.\n";
+        my $option = $config->{githooks}{groups};
 
-	if (my ($groupfile) = ($option->[-1] =~ /^file:(.*)/)) {
-	    my @groupspecs = read_file($groupfile);
-	    defined $groupspecs[0]
-		or die __PACKAGE__, ": can't open groups file ($groupfile): $!\n";
-	    grok_groups_spec(\@groupspecs, $groupfile);
-	} else {
-	    my @groupspecs = split /\n/, $option->[-1];
-	    grok_groups_spec(\@groupspecs, "githooks.groups");
-	}
+        if (my ($groupfile) = ($option->[-1] =~ /^file:(.*)/)) {
+            my @groupspecs = read_file($groupfile);
+            defined $groupspecs[0]
+                or die __PACKAGE__, ": can't open groups file ($groupfile): $!\n";
+            grok_groups_spec(\@groupspecs, $groupfile);
+        } else {
+            my @groupspecs = split /\n/, $option->[-1];
+            grok_groups_spec(\@groupspecs, "githooks.groups");
+        }
     };
     return $groups;
 }
@@ -216,13 +216,13 @@ sub im_memberof {
     state $groups = grok_groups();
 
     exists $groups->{$groupname}
-	or die __PACKAGE__, ": group $groupname is not defined.\n";
+        or die __PACKAGE__, ": group $groupname is not defined.\n";
 
     my $group = $groups->{$groupname};
     return 1 if exists $group->{$myself};
     while (my ($member, $subgroup) = each %$group) {
-	next     unless defined $subgroup;
-	return 1 if     im_memberof($myself, $member);
+        next     unless defined $subgroup;
+        return 1 if     im_memberof($myself, $member);
     }
     return 0;
 }
@@ -230,18 +230,18 @@ sub im_memberof {
 my $myself;
 sub grok_userenv {
     my $userenv = config()->{githooks}{userenv}
-	or return;
+        or return;
 
     $userenv = $userenv->[-1] if is_array_ref($userenv);
 
     if ($userenv =~ /^eval:(.*)/) {
-	$myself = eval $1; ## no critic (BuiltinFunctions::ProhibitStringyEval)
-	die __PACKAGE__, ": error evaluating userenv value ($userenv): $@\n"
-	    if $@;
+        $myself = eval $1; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+        die __PACKAGE__, ": error evaluating userenv value ($userenv): $@\n"
+            if $@;
     } elsif (exists $ENV{$userenv}) {
-	$myself = $ENV{$userenv};
+        $myself = $ENV{$userenv};
     } else {
-	die __PACKAGE__, ": option userenv environment variable ($userenv) is not defined.\n";
+        die __PACKAGE__, ": option userenv environment variable ($userenv) is not defined.\n";
     }
 
     return $myself;
@@ -254,11 +254,11 @@ sub match_user {
     return 0       unless defined $myself;
 
     if ($spec =~ /^\^/) {
-	return 1 if $myself =~ $spec;
+        return 1 if $myself =~ $spec;
     } elsif ($spec =~ /^@/) {
-	return 1 if im_memberof($myself, $spec);
+        return 1 if im_memberof($myself, $spec);
     } else {
-	return 1 if $myself eq $spec;
+        return 1 if $myself eq $spec;
     }
     return 0;
 }
@@ -267,9 +267,9 @@ sub im_admin {
     my $config = hook_config('githooks');
     return 0 unless defined $config and exists $config->{admin};
     foreach my $admin (@{$config->{admin}}) {
-	if (match_user($admin)) {
-	    return 1;
-	}
+        if (match_user($admin)) {
+            return 1;
+        }
     }
     return 0;
 }
@@ -280,17 +280,17 @@ sub eval_gitconfig {
     my $value;
 
     if ($config =~ s/^file://) {
-	$value = do $config;
-	unless ($value) {
-	    die "couldn't parse '$config': $@\n" if $@;
-	    die "couldn't do '$config': $!\n"    unless defined $value;
-	    die "couldn't run '$config'\n"       unless $value;
-	}
+        $value = do $config;
+        unless ($value) {
+            die "couldn't parse '$config': $@\n" if $@;
+            die "couldn't do '$config': $!\n"    unless defined $value;
+            die "couldn't run '$config'\n"       unless $value;
+        }
     } elsif ($config =~ s/^eval://) {
-	$value = eval $config; ## no critic (BuiltinFunctions::ProhibitStringyEval)
-	die "couldn't parse '$config':\n$@\n" if $@;
+        $value = eval $config; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+        die "couldn't parse '$config':\n$@\n" if $@;
     } else {
-	$value = $config;
+        $value = $config;
     }
 
     return $value;
@@ -327,52 +327,54 @@ sub run_hook {
 
     # Invoke enabled plugins
     if (my $enabled_plugins = $config->{$hook_name}) {
-	# Define the list of directories where we'll look for the hook
-	# plugins. First the local directory 'githooks' under the
-	# repository path, then the optional list of directories
-	# specified by the githooks.plugins config option, and,
-	# finally, the Git::Hooks standard hooks directory.
-	unshift @{$config->{plugins}}, 'githooks';
-	push    @{$config->{plugins}}, catfile(dirname($INC{'Git/Hooks.pm'}), 'Hooks');
-	my @plugin_dirs = grep {-d} @{$config->{plugins}};
+        # Define the list of directories where we'll look for the hook
+        # plugins. First the local directory 'githooks' under the
+        # repository path, then the optional list of directories
+        # specified by the githooks.plugins config option, and,
+        # finally, the Git::Hooks standard hooks directory.
+        unshift @{$config->{plugins}}, 'githooks';
+        push    @{$config->{plugins}}, catfile(dirname($INC{'Git/Hooks.pm'}), 'Hooks');
+        my @plugin_dirs = grep {-d} @{$config->{plugins}};
 
       HOOK:
-	foreach my $hook (@$enabled_plugins) {
-	    my $name = unflatten_plugin_name($hook);
-	    foreach my $dir (@plugin_dirs) {
-		my $script = catfile($dir, $name);
-		next unless -f $script;
+        foreach my $hook (@$enabled_plugins) {
+            my $name = unflatten_plugin_name($hook);
+            foreach my $dir (@plugin_dirs) {
+                my $script = catfile($dir, $name);
+                next unless -f $script;
 
-		my $exit = do $script;
-		unless ($exit) {
-		    die __PACKAGE__, ": couldn't parse $script: $@\n" if $@;
-		    die __PACKAGE__, ": couldn't do $script: $!\n"    unless defined $exit;
-		    die __PACKAGE__, ": couldn't run $script\n"       unless $exit;
-		}
-		next HOOK;
-	    }
-	    die __PACKAGE__, ": can't find enabled hook $hook (a.k.a. $name).\n";
-	}
+                my $exit = do $script;
+                unless ($exit) {
+                    die __PACKAGE__, ": couldn't parse $script: $@\n" if $@;
+                    die __PACKAGE__, ": couldn't do $script: $!\n"    unless defined $exit;
+                    die __PACKAGE__, ": couldn't run $script\n"       unless $exit;
+                }
+                next HOOK;
+            }
+            die __PACKAGE__, ": can't find enabled hook $hook (a.k.a. $name).\n";
+        }
     }
 
     # Call every hook function installed by the hook scripts before.
     foreach my $hook (values %{$Hooks{$hook_name}}) {
-	$hook->($git, @args);
+        $hook->($git, @args);
     }
 
     # Invoked enabled external hooks
-    unless (exists $config->{externals} && ! $config->{externals}[-1]) {
-	# By default, start looking for external hooks in the
-	# '.git/hooks.d' directory.
-	unshift @{$config->{hooks}}, catfile($git->repo_path(), 'hooks.d');
+    if (! exists $config->{externals} || $config->{externals}[-1]) {
+        # By default, start looking for external hooks in the
+        # '.git/hooks.d' directory.
+        unshift @{$config->{hooks}}, catfile($git->repo_path(), 'hooks.d');
 
-	foreach my $dir (grep {-e} map {catfile($_, $hook_name)} @{$config->{hooks}}) {
-	    opendir my $dh, $dir or die __PACKAGE__, ": cannot opendir $dir: $!\n";
-	    foreach my $file (grep {-f && -x} map {catfile($dir, $_)} readdir $dh) {
-		spawn_external_file($file, $hook_name, @args);
-	    }
-	}
+        foreach my $dir (grep {-e} map {catfile($_, $hook_name)} @{$config->{hooks}}) {
+            opendir my $dh, $dir or die __PACKAGE__, ": cannot opendir $dir: $!\n";
+            foreach my $file (grep {-f && -x} map {catfile($dir, $_)} readdir $dh) {
+                spawn_external_file($file, $hook_name, @args);
+            }
+        }
     }
+
+    return;
 }
 
 
@@ -388,37 +390,37 @@ Git::Hooks - A framework for implementing Git hooks.
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 SYNOPSIS
 
 A single script can implement several Git hooks:
 
-	#!/usr/bin/env perl
+        #!/usr/bin/env perl
 
-	use Git::Hooks;
+        use Git::Hooks;
 
-	PRE_COMMIT {
-	    my ($git) = @_;
-	    # ...
-	};
+        PRE_COMMIT {
+            my ($git) = @_;
+            # ...
+        };
 
-	COMMIT_MSG {
-	    my ($git, $msg_file) = @_;
-	    # ...
-	};
+        COMMIT_MSG {
+            my ($git, $msg_file) = @_;
+            # ...
+        };
 
-	run_hook($0, @ARGV);
+        run_hook($0, @ARGV);
 
 Or you can use Git::Hooks plugins or external hooks, driven by the
 single script below. These hooks are enabled by Git configuration
 options. (More on this later.)
 
-	#!/usr/bin/env perl
+        #!/usr/bin/env perl
 
-	use Git::Hooks;
+        use Git::Hooks;
 
-	run_hook($0, @ARGV);
+        run_hook($0, @ARGV);
 
 =for Pod::Coverage repository config grok_affected_refs spawn_external_file grok_groups_spec grok_groups
 
@@ -511,15 +513,15 @@ You should see there a bunch of files with names ending in C<.sample>
 which are hook examples. Create a three-line script called, e.g.,
 C<git-hooks.pl>, in this directory like this:
 
-	$ cd /path/to/repo/.git/hooks
+        $ cd /path/to/repo/.git/hooks
 
-	$ cat >git-hooks.pl <<EOT
-	#!/usr/bin/env perl
-	use Git::Hooks;
-	run_hook($0, @ARGV);
-	EOT
+        $ cat >git-hooks.pl <<EOT
+        #!/usr/bin/env perl
+        use Git::Hooks;
+        run_hook($0, @ARGV);
+        EOT
 
-	$ chmod +x git-hooks.pl
+        $ chmod +x git-hooks.pl
 
 Now you should create symbolic links pointing to it for each hook you
 are interested in. For example, if you are interested in a
@@ -531,9 +533,9 @@ script for all hooked operations, even for those that you may not be
 interested in. Nothing wrong will happen, but the server will be doing
 extra work for nothing.)
 
-	$ ln -s git-hooks.pl commit-msg
-	$ ln -s git-hooks.pl post-commit
-	$ ln -s git-hooks.pl pre-receive
+        $ ln -s git-hooks.pl commit-msg
+        $ ln -s git-hooks.pl post-commit
+        $ ln -s git-hooks.pl pre-receive
 
 As is, the script won't do anything. You have to implement some hooks
 in it, use some of the existing plugins, or set up some external
@@ -689,48 +691,56 @@ repository. Note that this will fetch all C<--system>, C<--global>,
 and C<--local> options, in this order. You may use this mechanism to
 define configuration global to a user or local to a repository.
 
-=head2 githooks.applypatch-msg     PLUGIN
+=head2 githooks.HOOK PLUGIN
 
-=head2 githooks.pre-applypatch     PLUGIN
-
-=head2 githooks.post-applypatch    PLUGIN
-
-=head2 githooks.pre-commit         PLUGIN
-
-=head2 githooks.prepare-commit-msg PLUGIN
-
-=head2 githooks.commit-msg  	   PLUGIN
-
-=head2 githooks.post-commit 	   PLUGIN
-
-=head2 githooks.pre-rebase  	   PLUGIN
-
-=head2 githooks.post-checkout      PLUGIN
-
-=head2 githooks.post-merge         PLUGIN
-
-=head2 githooks.pre-receive        PLUGIN
-
-=head2 githooks.update             PLUGIN
-
-=head2 githooks.post-receive       PLUGIN
-
-=head2 githooks.post-update        PLUGIN
-
-=head2 githooks.pre-auto-gc        PLUGIN
-
-=head2 githooks.post-rewrite       PLUGIN
-
-To enable a plugin you must register it with one of the above
-options. For instance, if you want to enable the C<CheckJira>
-plugin in the C<update> hook, you must do this:
+To enable a plugin you must register it to the appropriate Git hook.
+For instance, if you want to register the C<CheckJira> plugin in the
+C<update> hook, you must do this:
 
     $ git config --add githooks.update CheckJira
 
-(Up to version 0.022 of Git::Hooks, the plugin filename were in the
-form C<check-jira.pl>. The old form is still valid to preserve
-compatibility, but the standard CamelCase form for Perl module names
-are now prefered. The '.pl' extension in the plugin name is optional.)
+And if you want to register the C<CheckAcls> plugin in the
+C<pre-receive> hook, you must do this:
+
+    $ git config --add githooks.pre-receive CheckAcls
+
+The complete list of Git hooks that can be used is this: 
+
+=over 4
+
+=item githooks.applypatch-msg
+
+=item githooks.pre-applypatch
+
+=item githooks.post-applypatch
+
+=item githooks.pre-commit
+
+=item githooks.prepare-commit-msg
+
+=item githooks.commit-msg
+
+=item githooks.post-commit
+
+=item githooks.pre-rebase
+
+=item githooks.post-checkout
+
+=item githooks.post-merge
+
+=item githooks.pre-receive
+
+=item githooks.update
+
+=item githooks.post-receive
+
+=item githooks.post-update
+
+=item githooks.pre-auto-gc
+
+=item githooks.post-rewrite
+
+=back
 
 Note that you may enable more than one plugin to the same hook. For
 instance:
@@ -742,6 +752,11 @@ sense to do so. For instance:
 
     $ git config --add githooks.commit-msg CheckJira
 
+(Up to version 0.022 of Git::Hooks, the plugin filename were in the
+form C<check-jira.pl>. The old form is still valid to preserve
+compatibility, but the standard CamelCase form for Perl module names
+are now preferred. The '.pl' extension in the plugin name is optional.)
+
 =head2 githooks.plugins DIR
 
 The plugins enabled for a hook are searched for in three places. First
@@ -886,7 +901,7 @@ the basename of the parameter.
 The remaining arguments depend on the hook for which it's being
 called. Usually you just pass C<@ARGV> to it. And that's it. Mostly.
 
-	run_hook($0, @ARGV);
+        run_hook($0, @ARGV);
 
 =head1 HOOK DIRECTIVES
 
@@ -912,41 +927,45 @@ will prevent Git from finishing its operation.
 Also note that each hook directive can be called more than once if you
 need to implement more than one specific hook.
 
-=head2 APPLYPATCH_MSG(GIT, commit-msg-file)
+=over
 
-=head2 PRE_APPLYPATCH(GIT)
+=item APPLYPATCH_MSG(GIT, commit-msg-file)
 
-=head2 POST_APPLYPATCH(GIT)
+=item PRE_APPLYPATCH(GIT)
 
-=head2 PRE_COMMIT(GIT)
+=item POST_APPLYPATCH(GIT)
 
-=head2 PREPARE_COMMIT_MSG(GIT, commit-msg-file [, msg-src [, SHA1]])
+=item PRE_COMMIT(GIT)
 
-=head2 COMMIT_MSG(GIT, commit-msg-file)
+=item PREPARE_COMMIT_MSG(GIT, commit-msg-file [, msg-src [, SHA1]])
 
-=head2 POST_COMMIT(GIT)
+=item COMMIT_MSG(GIT, commit-msg-file)
 
-=head2 PRE_REBASE(GIT)
+=item POST_COMMIT(GIT)
 
-=head2 POST_CHECKOUT(GIT, prev-head-ref, new-head-ref, is-branch-checkout)
+=item PRE_REBASE(GIT)
 
-=head2 POST_MERGE(GIT, is-squash-merge)
+=item POST_CHECKOUT(GIT, prev-head-ref, new-head-ref, is-branch-checkout)
 
-=head2 PRE_RECEIVE(GIT)
+=item POST_MERGE(GIT, is-squash-merge)
 
-=head2 UPDATE(GIT, updated-ref-name, old-object-name, new-object-name)
+=item PRE_RECEIVE(GIT)
 
-=head2 POST_RECEIVE(GIT)
+=item UPDATE(GIT, updated-ref-name, old-object-name, new-object-name)
 
-=head2 POST_UPDATE(GIT, updated-ref-name, ...)
+=item POST_RECEIVE(GIT)
 
-=head2 PRE_AUTO_GC(GIT)
+=item POST_UPDATE(GIT, updated-ref-name, ...)
 
-=head2 POST_REWRITE(GIT, command)
+=item PRE_AUTO_GC(GIT)
+
+=item POST_REWRITE(GIT, command)
+
+=back
 
 =head1 METHODS FOR PLUGIN DEVELOPERS
 
-Plugins should start by importing the utility routines from
+plugins should start by importing the utility routines from
 Git::Hooks:
 
     use Git::Hooks qw/:utils/;
@@ -1051,13 +1070,13 @@ returned.
 
 This routine takes a name like C<Git::Hooks::CheckJira> and returns
 C<check-jira>. It takes the PACKAGENAME's basename, inserts hyphens
-between the CamelCased words and lowercase everything.
+between the CamelCase words and lowercase everything.
 
 =head2 unflatten_plugin_name(PLUGINNAME)
 
 This routine takes a name like C<check-jira.pl> and returns
 C<Git::Hooks::CheckJira>. It takes the PLUGINNAME, upcase the
-characteres following hyphens, removes the hyphens, and upcase the
+characters following hyphens, removes the hyphens, and upcase the
 first line. It also strips a trailing C<.pl>, if present.
 
 =head1 SEE ALSO
